Minos Microservice Networks
===========================

[![codecov](https://codecov.io/gh/Clariteia/minos_microservice_networks/branch/main/graph/badge.svg)](https://codecov.io/gh/Clariteia/minos_microservice_networks)

![Tests](https://github.com/Clariteia/minos_microservice_networks/actions/workflows/python-tests.yml/badge.svg)

Python Package with the common network classes and utlities used in Minos Microservice


Credits
-------

This package was created with ![Cookiecutter](https://github.com/audreyr/cookiecutter)
and the ![Minos Package](https://github.com/Clariteia/minos-pypackage) project template.
